@@ -20,9 +20,9 @@ import os
 import signal
 import subprocess
 
+from dirspec.basedir import load_data_paths
 from distutils.spawn import find_executable
 from urllib import quote
-from xdg.BaseDirectory import load_data_paths
 
 
 class DBusLaunchError(Exception):
